<?php declare(strict_types=1);

namespace Infomaker\Imengine\CropData;

use Infomaker\Everyware\Support\Format;
use Infomaker\Imengine\CropData\Interfaces\CropResizeDataInterface;

/**
 * Class CropResizeData
 *
 * @package Infomaker\Imengine
 */
class CropResizeData implements CropResizeDataInterface
{
    private $cropWidth;
    private $cropHeight;
    private $width;
    private $height;
    private $cropX = 0.0;
    private $cropY = 0.0;

    /**
     * CropResizeData constructor.
     *
     * @param float $cropWidth
     * @param float $cropHeight
     */
    public function __construct(float $cropWidth, float $cropHeight)
    {
        $this->cropWidth  = Format::formatNumberToImengineFloat($cropWidth);
        $this->cropHeight = Format::formatNumberToImengineFloat($cropHeight);
    }

    /**
     * @return int
     */
    public function getWidth(): int
    {
        return $this->width;
    }

    /**
     * @param mixed $width
     *
     * @return \Infomaker\Imengine\CropData\CropResizeData
     */
    public function setWidth(int $width): CropResizeData
    {
        $this->width = $width;

        return $this;
    }

    /**
     * @return int
     */
    public function getHeight(): int
    {
        return $this->height;
    }

    /**
     * @param mixed $height
     *
     * @return \Infomaker\Imengine\CropData\CropResizeData
     */
    public function setHeight(int $height): CropResizeData
    {
        $this->height = $height;

        return $this;
    }

    /**
     * @return float
     */
    public function getCropX(): float
    {
        return $this->cropX;
    }

    /**
     * @param float $cropX
     *
     * @return \Infomaker\Imengine\CropData\CropResizeData
     */
    public function setCropX(float $cropX): CropResizeData
    {
        $this->cropX = $cropX;

        return $this;
    }

    /**
     * @return float
     */
    public function getCropY(): float
    {
        return $this->cropY;
    }

    /**
     * @param float $cropY
     *
     * @return \Infomaker\Imengine\CropData\CropResizeData
     */
    public function setCropY(float $cropY): CropResizeData
    {
        $this->cropY = $cropY;

        return $this;
    }

    /**
     * @return float
     */
    public function getCropWidth(): float
    {
        return $this->cropWidth;
    }

    /**
     * @return float
     */
    public function getCropHeight(): float
    {
        return $this->cropHeight;
    }
}
